.. _spkg_sagemath_macaulay2_jupyterkernel:

sagemath_macaulay2_jupyterkernel: Jupyter kernel for Macaulay2
==============================================================

Description
-----------

Jupyter kernel for Macaulay2 (passagemath fork)

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/passagemath-macaulay2-jupyterkernel/


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_ipykernel`
- :ref:`spkg_pexpect`
- :ref:`spkg_sagemath_macaulay2`

Version Information
-------------------

requirements.txt::

    passagemath-macaulay2-jupyterkernel

Equivalent System Packages
--------------------------

(none known)
